@@ -38,7 +38,7 @@ func ResponseDiscriminatorUpdatedCheck(diffReport *diff.Diff, operationsSources
 			appendResultItem := func(messageId string, a ...any) {
 				result = append(result, NewApiChange(
 					messageId,
-					INFO,
+					config,
 					a,
 					"",
 					operationsSources,
