@@ -25,13 +25,15 @@ const (
 	ExcludeExtensionsOption  = "extensions"
 )
 
-var ExcludeDiffOptions = []string{
-	ExcludeExamplesOption,
-	ExcludeDescriptionOption,
-	ExcludeEndpointsOption,
-	ExcludeTitleOption,
-	ExcludeSummaryOption,
-	ExcludeExtensionsOption,
+func GetExcludeDiffOptions() []string {
+	return []string{
+		ExcludeExamplesOption,
+		ExcludeDescriptionOption,
+		ExcludeEndpointsOption,
+		ExcludeTitleOption,
+		ExcludeSummaryOption,
+		ExcludeExtensionsOption,
+	}
 }
 
 // NewConfig returns a default configuration
@@ -46,11 +48,6 @@ func (config *Config) WithExcludeElements(excludeElements []string) *Config {
 	return config
 }
 
-func (config *Config) WithExcludeExtensions() *Config {
-	config.ExcludeElements.Add(ExcludeExtensionsOption)
-	return config
-}
-
 func (config *Config) IsExcludeExamples() bool {
 	return config.ExcludeElements.Contains(ExcludeExamplesOption)
 }
